FLApplyJSONDelta

Function FLApplyJSONDelta 

pub unsafe extern "C" fn FLApplyJSONDelta(
    old: FLValue,
    jsonDelta: FLSlice,
    outError: *mut FLError,
) -> FLSliceResult
Applies the JSON data created by CreateJSONDelta to the value old, which must be equal to the old value originally passed to FLCreateJSONDelta, and returns a Fleece document equal to the original nuu value. @param old A value that’s typically the old/original state of some data. This must be equal to the old value used when creating the jsonDelta. @param jsonDelta A JSON-encoded delta created by FLCreateJSONDelta or FLEncodeJSONDelta. @param outError On failure, error information will be stored where this points, if non-null. @return The corresponding nuu value, encoded as Fleece, or null if an error occurred.