pub unsafe extern "C" fn FLArrayIterator_Next(
arg1: *mut FLArrayIterator,
) -> boolExpand description
Advances the iterator to the next value, or returns false if at the end.
pub unsafe extern "C" fn FLArrayIterator_Next(
arg1: *mut FLArrayIterator,
) -> boolAdvances the iterator to the next value, or returns false if at the end.