pub unsafe extern "C" fn FLDeepIterator_GetIndex(
arg1: FLDeepIterator,
) -> u32Expand description
Returns the array index of the current value in its parent, or 0 if not in an array.
pub unsafe extern "C" fn FLDeepIterator_GetIndex(
arg1: FLDeepIterator,
) -> u32Returns the array index of the current value in its parent, or 0 if not in an array.