pub unsafe extern "C" fn FLDeepIterator_Next(
arg1: FLDeepIterator,
) -> boolExpand description
Advances the iterator to the next value, or returns false if at the end.
pub unsafe extern "C" fn FLDeepIterator_Next(
arg1: FLDeepIterator,
) -> boolAdvances the iterator to the next value, or returns false if at the end.