pub unsafe extern "C" fn FLDeepIterator_SkipChildren(
arg1: FLDeepIterator,
)Expand description
Tells the iterator to skip the children of the current value.
pub unsafe extern "C" fn FLDeepIterator_SkipChildren(
arg1: FLDeepIterator,
)Tells the iterator to skip the children of the current value.