pub unsafe extern "C" fn FLDictIterator_GetKey(
arg1: *const FLDictIterator,
) -> FLValueExpand description
Returns the current key being iterated over. This Value will be a string or an integer.
pub unsafe extern "C" fn FLDictIterator_GetKey(
arg1: *const FLDictIterator,
) -> FLValueReturns the current key being iterated over. This Value will be a string or an integer.