pub unsafe extern "C" fn FLDictKey_Init(string: FLSlice) -> FLDictKeyExpand description
Initializes an FLDictKey struct with a key string. @warning The input string’s memory MUST remain valid for as long as the FLDictKey is in use! (The FLDictKey stores a pointer to the string, but does not copy it.) @param string The key string (UTF-8). @return An initialized FLDictKey struct.