FLEncoder_LastValueWritten

Function FLEncoder_LastValueWritten 

pub unsafe extern "C" fn FLEncoder_LastValueWritten(
    arg1: FLEncoder,
) -> isize
Returns an opaque reference to the last complete value written to the encoder, if possible. Fails (returning 0) if nothing has been written, or if the value is inline and can’t be referenced this way – that only happens with small scalars or empty collections.