FLEncoder_Snip

Function FLEncoder_Snip 

pub unsafe extern "C" fn FLEncoder_Snip(
    arg1: FLEncoder,
) -> FLSliceResult
Returns the data written so far as a standalone Fleece document, whose root is the last value written. You can continue writing, and the final output returned by \ref FLEncoder_Finish will consist of everything after this point. That second part can be used in the future by loading it as an FLDoc with the first part as its extern reference.