pub unsafe extern "C" fn FLMutableArray_IsChanged(
arg1: FLMutableArray,
) -> boolExpand description
Returns true if the Array has been changed from the source it was copied from.
pub unsafe extern "C" fn FLMutableArray_IsChanged(
arg1: FLMutableArray,
) -> boolReturns true if the Array has been changed from the source it was copied from.