pub unsafe extern "C" fn FLMutableDict_IsChanged(
arg1: FLMutableDict,
) -> boolExpand description
Returns true if the Dict has been changed from the source it was copied from.
pub unsafe extern "C" fn FLMutableDict_IsChanged(
arg1: FLMutableDict,
) -> boolReturns true if the Dict has been changed from the source it was copied from.