pub unsafe extern "C" fn FLSharedKeys_Count(
arg1: FLSharedKeys,
) -> c_uintExpand description
Returns the number of keys in the mapping. This number increases whenever the mapping is changed, and never decreases.
pub unsafe extern "C" fn FLSharedKeys_Count(
arg1: FLSharedKeys,
) -> c_uintReturns the number of keys in the mapping. This number increases whenever the mapping is changed, and never decreases.