pub unsafe extern "C" fn FLSharedKeys_GetStateData(
arg1: FLSharedKeys,
) -> FLSliceResultExpand description
Returns a data blob containing the current state (all the keys and their integers.)
pub unsafe extern "C" fn FLSharedKeys_GetStateData(
arg1: FLSharedKeys,
) -> FLSliceResultReturns a data blob containing the current state (all the keys and their integers.)