pub unsafe extern "C" fn FLSharedKeys_LoadState(
arg1: FLSharedKeys,
arg2: FLValue,
) -> boolExpand description
Updates an FLSharedKeys object with saved state, a Fleece value previously written by \ref FLSharedKeys_WriteState.
pub unsafe extern "C" fn FLSharedKeys_LoadState(
arg1: FLSharedKeys,
arg2: FLValue,
) -> boolUpdates an FLSharedKeys object with saved state, a Fleece value previously written by \ref FLSharedKeys_WriteState.