FLSharedKeys_WriteState

Function FLSharedKeys_WriteState 

pub unsafe extern "C" fn FLSharedKeys_WriteState(
    arg1: FLSharedKeys,
    arg2: FLEncoder,
)
Writes the current state to a Fleece encoder as a single value, which can later be decoded and passed to \ref FLSharedKeys_LoadState.