FLTimestamp_ToString

Function FLTimestamp_ToString 

pub unsafe extern "C" fn FLTimestamp_ToString(
    timestamp: FLTimestamp,
    asUTC: bool,
) -> FLStringResult
Formats a timestamp as a date-time string in ISO-8601 format. @note See also \ref FLEncoder_WriteDateString, which writes a timestamp to an FLEncoder. @param timestamp A time, given as milliseconds since the Unix epoch (1/1/1970 00:00 UTC.) @param asUTC If true, the timestamp will be given in universal time; if false, in the local timezone. @return A heap-allocated string, which you are responsible for releasing.