c4_getObjectCount

Function c4_getObjectCount 

pub unsafe extern "C" fn c4_getObjectCount() -> c_int
Returns the number of objects that have been created but not yet freed. This can be used as a debugging/testing tool to detect leaks; for example, capture the value at the start of a test, then call again at the end and compare.