c4_runAsyncTask

Function c4_runAsyncTask 

pub unsafe extern "C" fn c4_runAsyncTask(
    task: Option<unsafe extern "C" fn(arg1: *mut c_void)>,
    context: *mut c_void,
)
Schedules a function to be called asynchronously on a background thread. @param task A pointer to the function to run. It must take a single void* argument and return void. If it needs to return a value, it should call some other function you define and pass that value as a parameter. @param context An arbitrary pointer that will be passed to the function. You can use this to provide state. Obviously, whatever this points to must remain valid until the future time when task is called.