pub unsafe extern "C" fn c4blob_keyToString(
arg1: C4BlobKey,
) -> C4StringResultExpand description
Encodes a blob key to a string of the form “sha1-”+base64.
pub unsafe extern "C" fn c4blob_keyToString(
arg1: C4BlobKey,
) -> C4StringResultEncodes a blob key to a string of the form “sha1-”+base64.