c4blob_openWriteStream

Function c4blob_openWriteStream 

pub unsafe extern "C" fn c4blob_openWriteStream(
    arg1: *mut C4BlobStore,
    arg2: *mut C4Error,
) -> *mut C4WriteStream
Opens a write stream for creating a new blob. You should then call c4stream_write to write the data, ending with c4stream_install to compute the blob’s key and add it to the store, and then c4stream_closeWriter.