c4dbobs_createOnCollection

Function c4dbobs_createOnCollection 

pub unsafe extern "C" fn c4dbobs_createOnCollection(
    collection: *mut C4Collection,
    callback: C4CollectionObserverCallback,
    context: *mut c_void,
    error: *mut C4Error,
) -> *mut C4CollectionObserver
Creates a new collection observer, with a callback that will be invoked after one or more documents in the collection have changed. This is exactly like \ref c4dbobs_create, except that it acts on any collection. @param collection The collection to observe. @param callback The function to call after the collection changes. @param context An arbitrary value that will be passed to the callback. @return The new observer reference.