pub unsafe extern "C" fn c4doc_create(
db: *mut C4Database,
docID: C4String,
body: C4Slice,
revisionFlags: C4RevisionFlags,
error: *mut C4Error,
) -> *mut C4DocumentExpand description
Convenience function to create a new document. This just a wrapper around c4doc_put. If the document already exists, it will fail with the error kC4ErrorConflict. @param db The database to create the document in @param docID Document ID to create; if null, a UUID will be generated @param body Body of the document @param revisionFlags The flags of the new revision @param error Information about any error that occurred @return On success, a new C4Document with the new revision selected; else NULL.