c4enum_getDocument

Function c4enum_getDocument 

pub unsafe extern "C" fn c4enum_getDocument(
    e: *mut C4DocEnumerator,
    outError: *mut C4Error,
) -> *mut C4Document
Returns the current document, if any, from an enumerator. @param e The enumerator. @param outError Error will be stored here on failure. @return The document, or NULL if there is none or if an error occurred reading its body. Caller is responsible for calling c4document_free when done with it.