pub unsafe extern "C" fn c4error_getDescription(
error: C4Error,
) -> FLSliceResultExpand description
Returns a description of an error, including the domain and code as well as the message. Remember to free the result.
pub unsafe extern "C" fn c4error_getDescription(
error: C4Error,
) -> FLSliceResultReturns a description of an error, including the domain and code as well as the message. Remember to free the result.