pub unsafe extern "C" fn c4error_make(
domain: C4ErrorDomain,
code: c_int,
message: FLString,
) -> C4ErrorExpand description
Creates a C4Error struct with the given domain and code, and associates the message with it.
pub unsafe extern "C" fn c4error_make(
domain: C4ErrorDomain,
code: c_int,
message: FLString,
) -> C4ErrorCreates a C4Error struct with the given domain and code, and associates the message with it.