c4error_setCaptureBacktraces

Function c4error_setCaptureBacktraces 

pub unsafe extern "C" fn c4error_setCaptureBacktraces(arg1: bool)
If set to true, then when a C4Error is created the current thread’s stack backtrace will be captured along with it, and can later be examined by calling \ref c4error_getBacktrace. Even if false, some errors (like assertion failures) will still have backtraces.