pub unsafe extern "C" fn c4log_enableFatalExceptionBacktrace()Expand description
Registers a handler with the C++ runtime that will log a backtrace when an uncaught C++ exception occurs, just before the process aborts.
pub unsafe extern "C" fn c4log_enableFatalExceptionBacktrace()Registers a handler with the C++ runtime that will log a backtrace when an uncaught C++ exception occurs, just before the process aborts.