pub unsafe extern "C" fn c4log_flushLogFiles()Expand description
Ensures all log messages have been written to the current log files.
pub unsafe extern "C" fn c4log_flushLogFiles()Ensures all log messages have been written to the current log files.