pub unsafe extern "C" fn c4log_setBinaryFileLevel(level: C4LogLevel)Expand description
Sets the minimum level of log messages to be written to the log file.
pub unsafe extern "C" fn c4log_setBinaryFileLevel(level: C4LogLevel)Sets the minimum level of log messages to be written to the log file.