pub unsafe extern "C" fn c4log_setCallbackLevel(level: C4LogLevel)Expand description
Sets the minimum level of log messages to be reported via callback.
pub unsafe extern "C" fn c4log_setCallbackLevel(level: C4LogLevel)Sets the minimum level of log messages to be reported via callback.