c4query_setParameters

Function c4query_setParameters 

pub unsafe extern "C" fn c4query_setParameters(
    query: *mut C4Query,
    encodedParameters: C4String,
)
Sets the parameter values to use when running the query, if no parameters are given to \ref c4query_run. @param query The compiled query to run. @param encodedParameters JSON- or Fleece-encoded dictionary whose keys correspond to the named parameters in the query expression, and values correspond to the values to bind. Any unbound parameters will be null.