c4queryenum_close

Function c4queryenum_close 

pub unsafe extern "C" fn c4queryenum_close(
    arg1: *mut C4QueryEnumerator,
)
Closes an enumerator without freeing it. This is optional, but can be used to free up resources if the enumeration has not reached its end, but will not be freed for a while.