c4queryenum_getRowCount

Function c4queryenum_getRowCount 

pub unsafe extern "C" fn c4queryenum_getRowCount(
    e: *mut C4QueryEnumerator,
    outError: *mut C4Error,
) -> i64
Returns the total number of rows in the query, if known. Not all query enumerators may support this (but the current implementation does.) @param e The query enumerator @param outError On failure, an error will be stored here (probably kC4ErrorUnsupported.) @return The number of rows, or -1 on failure.