c4queryenum_next

Function c4queryenum_next 

pub unsafe extern "C" fn c4queryenum_next(
    e: *mut C4QueryEnumerator,
    outError: *mut C4Error,
) -> bool
Advances a query enumerator to the next row, populating its fields. Returns true on success, false at the end of enumeration or on error.