c4queryenum_seek

Function c4queryenum_seek 

pub unsafe extern "C" fn c4queryenum_seek(
    e: *mut C4QueryEnumerator,
    rowIndex: i64,
    outError: *mut C4Error,
) -> bool
Jumps to a specific row. Not all query enumerators may support this (but the current implementation does.) @param e The query enumerator @param rowIndex The number of the row, starting at 0, or -1 to restart before first row @param outError On failure, an error will be stored here (probably kC4ErrorUnsupported.) @return True on success, false on failure.