c4repl_setProgressLevel

Function c4repl_setProgressLevel 

pub unsafe extern "C" fn c4repl_setProgressLevel(
    repl: *mut C4Replicator,
    level: C4ReplicatorProgressLevel,
    outErr: *mut C4Error,
) -> bool
Sets the progress level of the replicator, indicating what information should be provided via callback.

@param repl The C4Replicator instance. @param level The progress level to set on the replicator @param outErr Records error information, if any. @return true if the progress level was set, false if there was an error.