FLDictKey

Struct FLDictKey 

#[repr(C)]
pub struct FLDictKey { pub _private1: FLSlice, pub _private2: *mut c_void, pub _private3: u32, pub private4: u32, pub private5: bool, }
Opaque key for a dictionary. You are responsible for creating space for these; they can go on the stack, on the heap, inside other objects, anywhere. Be aware that the lookup operations that use these will write into the struct to store “hints” that speed up future searches.

Fields

_private1: FLSlice_private2: *mut c_void_private3: u32private4: u32private5: bool