pub unsafe extern "C" fn FLDoc_FromJSON(
json: FLSlice,
outError: *mut FLError,
) -> FLDocExpand description
Creates an FLDoc from JSON-encoded data. The data is first encoded into Fleece, and the Fleece data is kept by the doc; the input JSON data is no longer needed after this function returns.