pub unsafe extern "C" fn FLKeyPath_EvalOnce(
specifier: FLSlice,
root: FLValue,
outError: *mut FLError,
) -> FLValueExpand description
Evaluates a key-path from a specifier string, for a given Fleece root object. If you only need to evaluate the path once, this is a bit faster than creating an FLKeyPath object, evaluating, then freeing it.