pub unsafe extern "C" fn FLMutableDict_Set(
arg1: FLMutableDict,
key: FLString,
) -> FLSlotExpand description
Returns an \ref FLSlot that refers to the given key/value pair of the given dictionary.
You store a value to it by calling one of the nine FLSlot_Set... functions.
\warning You should immediately store a value into the FLSlot. Do not keep it around;
any changes to the dictionary invalidate it.