pub unsafe extern "C" fn FLValue_NewString(arg1: FLString) -> FLValueExpand description
Allocates a string value on the heap. This is rarely needed – usually you’d just add a string to a mutable Array or Dict directly using one of their “…SetString” or “…AppendString” methods.