pub unsafe extern "C" fn c4db_getDefaultCollection(
db: *mut C4Database,
outError: *mut C4Error,
) -> *mut C4CollectionExpand description
Returns the default collection, whose name is “_default” (kC4DefaultCollectionName).
This is the one collection that exists in every newly created database.
When a pre-existing database is upgraded to support collections, all its documents are put
in the default collection.
@note Be sure to read C4Collection Lifespan in c4Collection.h.