pub unsafe extern "C" fn c4query_explain(
arg1: *mut C4Query,
) -> C4StringResultExpand description
Returns a string describing the implementation of the compiled query. This is intended to be read by a developer for purposes of optimizing the query, especially to add database indexes.