pub unsafe extern "C" fn c4queryobs_setEnabled(
obs: *mut C4QueryObserver,
enabled: bool,
)Expand description
Enables a query observer so its callback can be called, or disables it to stop callbacks.
When a query observer is enabled, its callback will be called with the current results. If this is the first observer, the query has to run first (on a background thread) so the callback will take a little while; if there are already enabled observers, the callback will be pretty much instantaneous.