#[repr(C)]pub struct FLSliceResult {
pub buf: *const c_void,
pub size: usize,
}Expand description
A heap-allocated block of memory returned from an API call.
The caller takes ownership, and must call \ref FLSliceResult_Release when done with it.
\warning The contents of the block must not be modified, since others may be using it.
\note This is equivalent to the C++ class alloc_slice. In C++ the easiest way to deal with
a FLSliceResult return value is to construct an alloc_slice from it, which will
adopt the reference, and release it in its destructor. For example:
alloc_slice foo( CopyFoo() );
Fields
buf: *const c_voidsize: usizeImplementations